==> img0ch-2.1.21.tar.bz2: img0ch/_template/zeromin2/init_install.cs <==
<?cs include:"zeromin2/header.cs" ?>

<div id="header">
  <div class="left">
    <p><a href="<?cs var:html_escape(ZerominScript) ?>">Zeromin</a></p>
  </div>

  <div class="right">
  </div>

  <div class="subheader">
  </div>
</div>

<div id="sidebar">
  <div>
    <p class="title"></p>
    <a href="javascript:void(0)" onclick="toggle('createUser')">ユーザー作成</a><br />
    <a href="javascript:void(0)" onclick="toggle('createCap')">キャップ作成</a><br />
    <a href="javascript:void(0)" onclick="toggle('createBBS')">掲示板作成</a><br />
  </div>
</div>

<div id="main">

  <div id="navhead">
    <hr />
  </div>

  <h1>インストール</h1>

<?cs if:Code0 ?><div class="noticeSuccess" id="notify"><p>インストールが完了しました</p></div><?cs /if ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>ユーザー名がありません</p></div><?cs /if ?>
<?cs if:Code3 ?><div class="noticeFailed" id="notify"><p>ユーザーのメールアドレスがありません</p></div><?cs /if ?>
<?cs if:Code4 ?><div class="noticeFailed" id="notify"><p>ユーザーのパスワードがありません</p></div><?cs /if ?>
<?cs if:Code5 ?><div class="noticeFailed" id="notify"><p>ユーザーの確認用パスワードがありません</p></div><?cs /if ?>
<?cs if:Code6 ?><div class="noticeFailed" id="notify"><p>ユーザーのパスワードが確認用と一致しません</p></div><?cs /if ?>
<?cs if:Code7 ?><div class="noticeFailed" id="notify"><p>ユーザーのメールアドレスが不正です</p></div><?cs /if ?>
<?cs if:Code8 ?><div class="noticeFailed" id="notify"><p>掲示板のディレクトリ名がありません</p></div><?cs /if ?>
<?cs if:Code9 ?><div class="noticeFailed" id="notify"><p>掲示板名がありません</p></div><?cs /if ?>
<?cs if:Code10 ?><div class="noticeFailed" id="notify"><p>掲示板副題がありません</p></div><?cs /if ?>
<?cs if:Code11 ?><div class="noticeFailed" id="notify"><p>掲示板のディレクトリ名が不正です</p></div><?cs /if ?>
<?cs if:Code12 ?><div class="noticeFailed" id="notify"><p>キャップ名がありません</p></div><?cs /if ?>
<?cs if:Code13 ?><div class="noticeFailed" id="notify"><p>キャップのパスワードがありません</p></div><?cs /if ?>
<?cs if:Code14 ?><div class="noticeFailed" id="notify"><p>キャップの確認用パスワードがありません</p></div><?cs /if ?>
<?cs if:Code15 ?><div class="noticeFailed" id="notify"><p>キャップのパスワードが確認用と一致しません</p></div><?cs /if ?>
<?cs if:Code16 ?><div class="noticeFailed" id="notify"><p>既にインストール作業が完了しています</p></div><?cs /if ?>
<?cs if:Code17 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>BBSPath</code>はディレクトリである必要があります</p></div><?cs /if ?>
<?cs if:Code18 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>BBSPath</code>から読み込みアクセス出来ません</p></div><?cs /if ?>
<?cs if:Code19 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>BBSPath</code>から書き込みアクセス出来ません</p></div><?cs /if ?>
<?cs if:Code20 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>BBSPath</code>から走査(実行)アクセス出来ません</p></div><?cs /if ?>
<?cs if:Code21 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>RepositoryRoot</code>はディレクトリである必要があります</p></div><?cs /if ?>
<?cs if:Code22 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>RepositoryRoot</code>から読み込みアクセス出来ません</p></div><?cs /if ?>
<?cs if:Code23 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>RepositoryRoot</code>から書き込みアクセス出来ません</p></div><?cs /if ?>
<?cs if:Code24 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>RepositoryRoot</code>から走査(実行)アクセス出来ません</p></div><?cs /if ?>
<?cs if:Error ?><div class="noticeFailed" id="notify"><p><?cs var:html_escape(Error) ?></p></div><?cs /if ?>
<?cs if:!Entries ?><div class="" id="notify"></div><?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/metadata.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/validate.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
<!--
jQuery(function(){
/*
jQuery("form#installForm").validate({
    "rules": {
        "user_name": {
            "required": true },
        "user_mail": {
            "email": true,
            "required": true },
        "user_pass": {
            "minLength": 6,
            "required": true },
        "user_confirm": {
            "equalTo": "input[@name='pass']",
            "minLength": 6,
            "required": true },
        "cap_name": {
            "required": true },
        "cap_pass": {
            "minLength": 6,
            "required": true },
        "cap_confirm": {
            "equalTo": "input[@name='cap_pass']",
            "minLength": 6,
            "required": true }
    },
    "messages": {
        "user_name": {
            "required": "名前欄を入力してください" },
        "user_mail": {
            "email": "正しいメールアドレスを入力してください",
            "required": "メールアドレスを入力してください" },
        "user_pass": {
            "minLength": "最低でも6文字以上入力してください",
            "required": "パスワードを入力してください" },
        "user_confirm": {
            "equalTo": "パスワードが一致していません",
            "minLength": "最低でも6文字以上入力してください",
            "required": "確認用のパスワードを入力してください" },
        "cap_name": {
            "required": "名前欄を入力してください" },
        "cap_pass": {
            "minLength": "最低でも6文字以上入力してください",
            "required": "パスワードを入力してください" },
        "cap_confirm": {
            "equalTo": "パスワードが一致していません",
            "minLength": "最低でも6文字以上入力してください",
            "required": "確認用のパスワードを入力してください" }
    },
    "showErrors": Zeromin2.getFormErrorHandler("以下の入力エラーがあります")
});
*/
jQuery("div.beHidden").hide();
});
function toggle(show) {
    jQuery("div.formContainer").hide();
    jQuery("div#" + show).show();
}
//-->
</script>

<form id="installForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="description">
これからインストールを行います。<br />
ユーザー作成、キャップ作成、掲示板作成の順でフォームを入力し、<br />
「インストール開始」をクリックしてください。<br />
<br />
<a href="javascript:void(0)" onclick="toggle('createUser')">ユーザー作成</a>
<a href="javascript:void(0)" onclick="toggle('createCap')">キャップ作成</a>
<a href="javascript:void(0)" onclick="toggle('createBBS')">掲示板作成</a>
</div>

<div class="highlight clearboxes formContainer" id="createUser" title="ユーザー作成">
<label for="user_name" title="user_name">名前</label>
<input type="text" id="user_name" name="user_name" title="user_name" value="<?cs if:UserName ?><?cs var:html_escape(UserName) ?><?cs else ?>管理人<?cs /if ?>" />
<label for="user_mail" title="user_mail">メールアドレス</label>
<input type="text" id="user_mail" name="user_mail" title="user_mail" value="<?cs if:UserMail ?><?cs var:html_escape(UserMail) ?><?cs else ?>dev@slash.null<?cs /if ?>" />
<label for="user_pass" title="user_pass">パスワード</label>
<input type="password" id="user_pass" name="user_pass" title="user_pass" value="<?cs var:html_escape(UserPass) ?>" />
<label for="user_confirm" title="user_confirm">パスワード(確認用)</label>
<input type="password" id="user_confirm" name="user_confirm" title="user_confirm" value="<?cs var:html_escape(UserConfirm) ?>" />
</div>

<div class="highlight clearboxes formContainer beHidden" id="createCap" title="キャップ作成">
<label for="create_cap" title="create_cap">&nbsp;キャップの作成を行うか</label>
<input type="checkbox" id="create_cap" name="create_cap" value="1" />作成する
<label for="cap_name" title="cap_name">名前</label>
<input type="text" id="cap_name" name="cap_name" title="cap_name" value="<?cs if:CapName ?><?cs var:html_escape(CapName) ?><?cs else ?>管理人<?cs /if ?>" />
<label for="cap_pass" title="cap_pass">パスワード</label>
<input type="password" id="cap_pass" name="cap_pass" title="cap_pass" value="<?cs var:html_escape(CapPass) ?>" />
<label for="cap_confirm" title="cap_confirm">パスワード(確認用)</label>
<input type="password" id="cap_confirm" name="cap_confirm" title="cap_confirm" value="<?cs var:html_escape(CapConfirm) ?>" />
</div>

<div class="highlight clearboxes formContainer beHidden" id="createBBS" title="掲示板作成">
<label for="create_bbs" title="create_bbs">&nbsp;掲示板の作成を行うか</label>
<input type="checkbox" id="create_bbs" name="create_bbs" value="1" />作成する
<label for="dir" title="dir">ディレクトリ名</label>
<input type="text" id="dir" name="dir" title="dir" value="<?cs if:BBSDir ?><?cs var:html_escape(BBSDir) ?><?cs else ?>bbs<?cs /if ?>" />
<label for="BBS_TITLE" title="BBS_TITLE">掲示板名</label>
<input type="text" id="BBS_TITLE" name="BBS_TITLE" title="BBS_TITLE" value="<?cs if:BBSName ?><?cs var:html_escape(BBSName) ?><?cs else ?>掲示板＠名前募集中<?cs /if ?>" />
<label for="BBS_SUBTITLE" title="BBS_SUBTITLE">掲示板副題</label>
<input type="text" id="BBS_SUBTITLE" name="BBS_SUBTITLE" title="BBS_SUBTITLE" value="<?cs if:BBSSubName ?><?cs var:html_escape(BBSSubName) ?><?cs else ?>何をするか意見を募集中です<?cs /if ?>" />
<label for="upload" title="upload">アップロードの許可</label>
<input type="checkbox" id="upload" name="upload" title="upload" value="1" />&nbsp;許可する
</div>

<div class="formFooter" id="startInstall">
<input type="hidden" name="class" value="init" />
<input type="hidden" name="method" value="install" />
<input type="hidden" name="OK" value="install" />
<input type="hidden" name="NG" value="install" />
<input type="submit" value="インストール開始" />
</div>

</form>

  <br id="endmain" />
</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.1.6.tar.bz2: img0ch/_template/zeromin2/init_install.cs <==
<?cs include:"zeromin2/header.cs" ?>

<div id="header">
  <div class="left">
    <p><a href="<?cs var:html_escape(ZerominScript) ?>">Zeromin</a></p>
  </div>

  <div class="right">
  </div>

  <div class="subheader">
  </div>
</div>

<div id="sidebar">
  <div>
    <p class="title"></p>
    <a href="javascript:void(0)" onclick="toggle('createUser')">ユーザー作成</a><br />
    <a href="javascript:void(0)" onclick="toggle('createCap')">キャップ作成</a><br />
    <a href="javascript:void(0)" onclick="toggle('createBBS')">掲示板作成</a><br />
  </div>
</div>

<div id="main">

  <div id="navhead">
    <hr />
  </div>

  <h1>インストール</h1>

<?cs if:Code0 ?><div class="noticeSuccess" id="notify"><p>インストールが完了しました</p></div><?cs /if ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>ユーザー名がありません</p></div><?cs /if ?>
<?cs if:Code3 ?><div class="noticeFailed" id="notify"><p>ユーザーのメールアドレスがありません</p></div><?cs /if ?>
<?cs if:Code4 ?><div class="noticeFailed" id="notify"><p>ユーザーのパスワードがありません</p></div><?cs /if ?>
<?cs if:Code5 ?><div class="noticeFailed" id="notify"><p>ユーザーの確認用パスワードがありません</p></div><?cs /if ?>
<?cs if:Code6 ?><div class="noticeFailed" id="notify"><p>ユーザーのパスワードが確認用と一致しません</p></div><?cs /if ?>
<?cs if:Code7 ?><div class="noticeFailed" id="notify"><p>ユーザーのメールアドレスが不正です</p></div><?cs /if ?>
<?cs if:Code8 ?><div class="noticeFailed" id="notify"><p>掲示板のディレクトリ名がありません</p></div><?cs /if ?>
<?cs if:Code9 ?><div class="noticeFailed" id="notify"><p>掲示板名がありません</p></div><?cs /if ?>
<?cs if:Code10 ?><div class="noticeFailed" id="notify"><p>掲示板副題がありません</p></div><?cs /if ?>
<?cs if:Code11 ?><div class="noticeFailed" id="notify"><p>掲示板のディレクトリ名が不正です</p></div><?cs /if ?>
<?cs if:Code12 ?><div class="noticeFailed" id="notify"><p>キャップ名がありません</p></div><?cs /if ?>
<?cs if:Code13 ?><div class="noticeFailed" id="notify"><p>キャップのパスワードがありません</p></div><?cs /if ?>
<?cs if:Code14 ?><div class="noticeFailed" id="notify"><p>キャップの確認用パスワードがありません</p></div><?cs /if ?>
<?cs if:Code15 ?><div class="noticeFailed" id="notify"><p>キャップのパスワードが確認用と一致しません</p></div><?cs /if ?>
<?cs if:Code16 ?><div class="noticeFailed" id="notify"><p>既にインストール作業が完了しています</p></div><?cs /if ?>
<?cs if:Code17 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>BBSPath</code>はディレクトリである必要があります</p></div><?cs /if ?>
<?cs if:Code18 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>BBSPath</code>から読み込みアクセス出来ません</p></div><?cs /if ?>
<?cs if:Code19 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>BBSPath</code>から書き込みアクセス出来ません</p></div><?cs /if ?>
<?cs if:Code20 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>BBSPath</code>から走査(実行)アクセス出来ません</p></div><?cs /if ?>
<?cs if:Code21 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>RepositoryRoot</code>はディレクトリである必要があります</p></div><?cs /if ?>
<?cs if:Code22 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>RepositoryRoot</code>から読み込みアクセス出来ません</p></div><?cs /if ?>
<?cs if:Code23 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>RepositoryRoot</code>から書き込みアクセス出来ません</p></div><?cs /if ?>
<?cs if:Code24 ?><div class="noticeFailed" id="notify"><p>img0ch-config.cgiの<code>RepositoryRoot</code>から走査(実行)アクセス出来ません</p></div><?cs /if ?>
<?cs if:Error ?><div class="noticeFailed" id="notify"><p><?cs var:html_escape(Error) ?></p></div><?cs /if ?>
<?cs if:!Entries ?><div class="" id="notify"></div><?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/metadata.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/validate.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
<!--
jQuery(function(){
/*
jQuery("#installForm").validate({
    "rules": {
        "user_name": {
            "required": true },
        "user_mail": {
            "email": true,
            "required": true },
        "user_pass": {
            "minLength": 6,
            "required": true },
        "user_confirm": {
            "equalTo": "input[@name='pass']",
            "minLength": 6,
            "required": true },
        "cap_name": {
            "required": true },
        "cap_pass": {
            "minLength": 6,
            "required": true },
        "cap_confirm": {
            "equalTo": "input[@name='cap_pass']",
            "minLength": 6,
            "required": true }
    },
    "messages": {
        "user_name": {
            "required": "名前欄を入力してください" },
        "user_mail": {
            "email": "正しいメールアドレスを入力してください",
            "required": "メールアドレスを入力してください" },
        "user_pass": {
            "minLength": "最低でも6文字以上入力してください",
            "required": "パスワードを入力してください" },
        "user_confirm": {
            "equalTo": "パスワードが一致していません",
            "minLength": "最低でも6文字以上入力してください",
            "required": "確認用のパスワードを入力してください" },
        "cap_name": {
            "required": "名前欄を入力してください" },
        "cap_pass": {
            "minLength": "最低でも6文字以上入力してください",
            "required": "パスワードを入力してください" },
        "cap_confirm": {
            "equalTo": "パスワードが一致していません",
            "minLength": "最低でも6文字以上入力してください",
            "required": "確認用のパスワードを入力してください" }
    },
    "showErrors": Zeromin2.getFormErrorHandler("以下の入力エラーがあります")
});
*/
jQuery("div.beHidden").hide();
});
function toggle(show) {
    jQuery("div.formContainer").hide();
    jQuery("#" + show).show();
}
//-->
</script>

<form id="installForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="description">
これからインストールを行います。<br />
ユーザー作成、キャップ作成、掲示板作成の順でフォームを入力し、<br />
「インストール開始」をクリックしてください。<br />
<br />
<a href="javascript:void(0)" onclick="toggle('createUser')">ユーザー作成</a>
<a href="javascript:void(0)" onclick="toggle('createCap')">キャップ作成</a>
<a href="javascript:void(0)" onclick="toggle('createBBS')">掲示板作成</a>
</div>

<div class="highlight clearboxes formContainer" id="createUser" title="ユーザー作成">
<label for="user_name" title="user_name">名前</label>
<input type="text" id="user_name" name="user_name" title="user_name" value="<?cs if:UserName ?><?cs var:html_escape(UserName) ?><?cs else ?>管理人<?cs /if ?>" />
<label for="user_mail" title="user_mail">メールアドレス</label>
<input type="text" id="user_mail" name="user_mail" title="user_mail" value="<?cs if:UserMail ?><?cs var:html_escape(UserMail) ?><?cs else ?>dev@slash.null<?cs /if ?>" />
<label for="user_pass" title="user_pass">パスワード</label>
<input type="password" id="user_pass" name="user_pass" title="user_pass" value="<?cs var:html_escape(UserPass) ?>" />
<label for="user_confirm" title="user_confirm">パスワード(確認用)</label>
<input type="password" id="user_confirm" name="user_confirm" title="user_confirm" value="<?cs var:html_escape(UserConfirm) ?>" />
</div>

<div class="highlight clearboxes formContainer beHidden" id="createCap" title="キャップ作成">
<label for="create_cap" title="create_cap">&nbsp;キャップの作成を行うか</label>
<input type="checkbox" id="create_cap" name="create_cap" value="1" />作成する
<label for="cap_name" title="cap_name">名前</label>
<input type="text" id="cap_name" name="cap_name" title="cap_name" value="<?cs if:CapName ?><?cs var:html_escape(CapName) ?><?cs else ?>管理人<?cs /if ?>" />
<label for="cap_pass" title="cap_pass">パスワード</label>
<input type="password" id="cap_pass" name="cap_pass" title="cap_pass" value="<?cs var:html_escape(CapPass) ?>" />
<label for="cap_confirm" title="cap_confirm">パスワード(確認用)</label>
<input type="password" id="cap_confirm" name="cap_confirm" title="cap_confirm" value="<?cs var:html_escape(CapConfirm) ?>" />
</div>

<div class="highlight clearboxes formContainer beHidden" id="createBBS" title="掲示板作成">
<label for="create_bbs" title="create_bbs">&nbsp;掲示板の作成を行うか</label>
<input type="checkbox" id="create_bbs" name="create_bbs" value="1" />作成する
<label for="dir" title="dir">ディレクトリ名</label>
<input type="text" id="dir" name="dir" title="dir" value="<?cs if:BBSDir ?><?cs var:html_escape(BBSDir) ?><?cs else ?>bbs<?cs /if ?>" />
<label for="BBS_TITLE" title="BBS_TITLE">掲示板名</label>
<input type="text" id="BBS_TITLE" name="BBS_TITLE" title="BBS_TITLE" value="<?cs if:BBSName ?><?cs var:html_escape(BBSName) ?><?cs else ?>掲示板＠名前募集中<?cs /if ?>" />
<label for="BBS_SUBTITLE" title="BBS_SUBTITLE">掲示板副題</label>
<input type="text" id="BBS_SUBTITLE" name="BBS_SUBTITLE" title="BBS_SUBTITLE" value="<?cs if:BBSSubName ?><?cs var:html_escape(BBSSubName) ?><?cs else ?>何をするか意見を募集中です<?cs /if ?>" />
<label for="upload" title="upload">アップロードの許可</label>
<input type="checkbox" id="upload" name="upload" title="upload" value="1" />&nbsp;許可する
<label for="utf8" title="utf8">国際化のため文字コードをUTF-8にする</label>
<input type="checkbox" id="utf8" name="utf8" title="utf8" value="1" />&nbsp;UTF-8にする
</div>

<div class="formFooter" id="startInstall">
<input type="hidden" name="class" value="init" />
<input type="hidden" name="method" value="install" />
<input type="hidden" name="OK" value="install" />
<input type="hidden" name="NG" value="install" />
<input type="submit" value="インストール開始" />
</div>

</form>

  <br id="endmain" />
</div>

<?cs include:"zeromin2/footer.cs" ?>
